@@ -11,11 +11,18 @@
 
 // we only use the plugins when loaded into the main application. Thus they do not need
 // their own KComponentData
-K3b::PluginConfigWidget::PluginConfigWidget( QWidget* parent, const QVariantList& args )
-    : KCModule( parent, args )
+K3b::PluginConfigWidget::PluginConfigWidget(QObject *parent, const KPluginMetaData& metaData, const QVariantList& args )
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    : KCModule( qobject_cast<QWidget *>(parent), args )
 {
+    Q_UNUSED(metaData);
 }
-
+#else
+    : KCModule( parent, metaData )
+{
+    Q_UNUSED(args);
+}
+#endif
 
 K3b::PluginConfigWidget::~PluginConfigWidget()
 {
@@ -51,4 +58,4 @@ void K3b::PluginConfigWidget::saveConfig( KConfigGroup )
 }
 #endif
 
-
+#include "moc_k3bpluginconfigwidget.cpp"
