@@ -43,12 +43,12 @@ namespace {
 K3B_EXPORT_PLUGIN_CONFIG_WIDGET( kcm_k3blameencoder, K3bLameEncoderSettingsWidget )
 
 
-K3bLameEncoderSettingsWidget::K3bLameEncoderSettingsWidget( QWidget* parent, const QVariantList& args )
-    : K3b::PluginConfigWidget( parent, args )
+K3bLameEncoderSettingsWidget::K3bLameEncoderSettingsWidget( QObject* parent, const KPluginMetaData& metaData, const QVariantList& args )
+    : K3b::PluginConfigWidget( parent, metaData, args )
 {
-    setupUi( this );
+    setupUi( widget() );
 
-    m_manualSettingsDialog = new K3bLameManualSettingsDialog( this );
+    m_manualSettingsDialog = new K3bLameManualSettingsDialog( widget() );
     for( int i = 0; s_lame_bitrates[i]; ++i )
         m_manualSettingsDialog->m_comboMaximumBitrate->addItem( i18n("%1 kbps" , s_lame_bitrates[i]) );
 
@@ -116,16 +116,16 @@ void K3bLameEncoderSettingsWidget::updateManualSettingsLabel()
     if( m_manualSettingsDialog->m_radioConstantBitrate->isChecked() )
         m_labelManualSettings->setText( i18n("Constant Bitrate: %1 kbps (%2)",
                                              s_lame_bitrates[m_manualSettingsDialog->m_comboConstantBitrate->currentIndex()],
-                                             i18n(s_lame_mode_strings[m_manualSettingsDialog->m_comboMode->currentIndex()])) );
+                                             s_lame_mode_strings[m_manualSettingsDialog->m_comboMode->currentIndex()].toString()) );
     else
         m_labelManualSettings->setText( i18n("Variable Bitrate (%1)",
-                                        i18n(s_lame_mode_strings[m_manualSettingsDialog->m_comboMode->currentIndex()])) );
+                                        s_lame_mode_strings[m_manualSettingsDialog->m_comboMode->currentIndex()].toString()) );
 }
 
 
 void K3bLameEncoderSettingsWidget::slotQualityLevelChanged( int val )
 {
-    m_labelQualityLevel->setText( i18n(s_lame_preset_strings[val]) );
+    m_labelQualityLevel->setText( s_lame_preset_strings[val].toString() );
 }
 
 
@@ -254,7 +254,9 @@ void K3bLameEncoderSettingsWidget::defaults()
     m_spinEncoderQuality->setValue( DEFAULT_ENCODER_QUALITY );
 
     updateManualSettingsLabel();
-    emit changed( true );
+    setNeedsSave( true );
 }
 
 #include "k3blameencoderconfigwidget.moc"
+
+#include "moc_k3blameencoderconfigwidget.cpp"
