@@ -103,7 +103,7 @@ void K3b::JobProgressDialog::setupGUI()
     headerParentFrame->setLineWidth( 1 );
     headerParentFrame->setLayout( new QVBoxLayout() );
     headerParentFrame->layout()->setSpacing(0);
-    headerParentFrame->layout()->setMargin(0);
+    headerParentFrame->layout()->setContentsMargins(0, 0, 0, 0);
 
     d->headerFrame = new QFrame( headerParentFrame );
     d->headerFrame->setFrameStyle( QFrame::NoFrame );
@@ -156,7 +156,7 @@ void K3b::JobProgressDialog::setupGUI()
     progressHeaderParentFrame->setLineWidth( 1 );
     progressHeaderParentFrame->setLayout( new QVBoxLayout() );
     progressHeaderParentFrame->layout()->setSpacing(0);
-    progressHeaderParentFrame->layout()->setMargin(0);
+    progressHeaderParentFrame->layout()->setContentsMargins(0, 0, 0, 0);
 
     d->progressHeaderFrame = new QFrame( progressHeaderParentFrame );
     d->progressHeaderFrame->setFrameStyle( QFrame::NoFrame );
@@ -479,7 +479,11 @@ void K3b::JobProgressDialog::setJob( K3b::Job* job )
 void K3b::JobProgressDialog::reject()
 {
     if( m_job && m_job->active() ) {
-        if( KMessageBox::questionYesNo( this, i18n("Do you really want to cancel?"), i18n("Cancel Confirmation") ) == KMessageBox::Yes ) {
+        if( KMessageBox::questionTwoActions( this,
+                                             i18n("Do you really want to cancel?"),
+                                             i18n("Cancel Confirmation"),
+                                             KStandardGuiItem::ok(),
+                                             KStandardGuiItem::cancel()) == KMessageBox::PrimaryAction ) {
             if( m_job ) {
                 m_job->cancel();
                 m_closeButton->setEnabled(true);
@@ -624,11 +628,11 @@ bool K3b::JobProgressDialog::questionYesNo( const QString& text,
                                             const KGuiItem& buttonYes,
                                             const KGuiItem& buttonNo )
 {
-    return ( KMessageBox::questionYesNo( this,
-                                         text,
-                                         caption,
-                                         buttonYes,
-                                         buttonNo ) == KMessageBox::Yes );
+    return ( KMessageBox::questionTwoActions( this,
+                                              text,
+                                              caption,
+                                              buttonYes,
+                                              buttonNo ) == KMessageBox::PrimaryAction );
 }
 
 
@@ -649,4 +653,4 @@ void K3b::JobProgressDialog::slotThemeChanged()
     }
 }
 
-
+#include "moc_k3bjobprogressdialog.cpp"
