@@ -44,6 +44,7 @@
 #include <KMessageBox>
 #include <KStandardGuiItem>
 #include <KUrlRequester>
+#include <kio_version.h>
 
 #include <QFile>
 #include <QFileInfo>
@@ -441,19 +442,29 @@ void K3b::ImageWritingDialog::setupGui()
     // -----------------------------------------------------------------------
     QGroupBox* groupImageUrl = new QGroupBox( i18n("Image to Burn"), frame );
     d->comboRecentImages = new KComboBox( true, this );
-    d->comboRecentImages->setSizeAdjustPolicy( QComboBox::AdjustToMinimumContentsLength );
+    d->comboRecentImages->setSizeAdjustPolicy( QComboBox::AdjustToMinimumContentsLengthWithIcon );
     d->editImagePath = new KUrlRequester( d->comboRecentImages, groupImageUrl );
     d->editImagePath->setMode( KFile::File|KFile::ExistingOnly );
     d->editImagePath->setWindowTitle( i18n("Choose Image File") );
-    d->editImagePath->setFilter( i18n("*.iso *.toc *.ISO *.TOC *.cue *.CUE|Image Files")
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 108, 0)
+    d->editImagePath->setNameFilters({
+        i18n("Image Files") + " (*.iso *.toc *.ISO *.TOC *.cue *.CUE)",
+        i18n("ISO 9660 Image Files") + " (*.iso *.ISO)",
+        i18n("Cue Files") + " (*.cue *.CUE)",
+        i18n("Cdrdao TOC Files and Cdrecord Clone Images") + " (*.toc *.TOC)",
+        i18n("All Files") + " (*)",
+    });
+#else
+    d->editImagePath->setFilter( "*.iso *.toc *.ISO *.TOC *.cue *.CUE|" + i18n("Image Files")
                                 + '\n'
-                                + i18n("*.iso *.ISO|ISO 9660 Image Files")
+                                + "*.iso *.ISO|" + i18n("ISO 9660 Image Files")
                                 + '\n'
-                                + i18n("*.cue *.CUE|Cue Files")
+                                + "*.cue *.CUE|" + i18n("Cue Files")
                                 + '\n'
-                                + i18n("*.toc *.TOC|Cdrdao TOC Files and Cdrecord Clone Images")
+                                + "*.toc *.TOC|" + i18n("Cdrdao TOC Files and Cdrecord Clone Images")
                                 + '\n'
-                                + i18n("*|All Files") );
+                                + "*|" + i18n("All Files") );
+#endif
     QHBoxLayout* groupImageUrlLayout = new QHBoxLayout( groupImageUrl );
     groupImageUrlLayout->addWidget( d->editImagePath );
 
@@ -704,13 +715,13 @@ void K3b::ImageWritingDialog::slotStartClicked()
             K3b::Iso9660 isoFs(d->imageFile);
             if (isoFs.open()) {
                 if (K3b::filesize(QUrl::fromLocalFile(d->imageFile)) < Private::volumeSpaceSize(isoFs)) {
-                    if (KMessageBox::questionYesNo(this,
-                                                   i18n("<p>The actual file size does not match the size declared in the file header. "
-                                                     "If it has been downloaded make sure the download is complete.</p>"
-                                                     "<p>Only continue if you know what you are doing.</p>"),
-                                                   i18n("Warning"),
-                                                   KStandardGuiItem::cont(),
-                                                   KStandardGuiItem::cancel() ) == KMessageBox::No )
+                    if (KMessageBox::questionTwoActions(this,
+                                                        i18n("<p>The actual file size does not match the size declared in the file header. "
+                                                             "If it has been downloaded make sure the download is complete.</p>"
+                                                             "<p>Only continue if you know what you are doing.</p>"),
+                                                        i18n("Warning"),
+                                                        KStandardGuiItem::cont(),
+                                                        KStandardGuiItem::cancel() ) == KMessageBox::SecondaryAction )
                         return;
                 }
             }
@@ -864,9 +875,11 @@ void K3b::ImageWritingDialog::slotUpdateImage( const QString& )
 
         // TODO: treat unusable image to opaque
         if (d->foundImageType == IMAGE_UNKNOWN) {
-            if (KMessageBox::questionYesNo(this,
-                                           i18n("Type of image file is not recognizable. Do you want to burn it anyway?"),
-                                           i18n("Unknown image type")) == KMessageBox::Yes) {
+            if (KMessageBox::questionTwoActions(this,
+                                                i18n("Type of image file is not recognizable. Do you want to burn it anyway?"),
+                                                i18n("Unknown image type"),
+                                                KGuiItem(i18n("Burn")),
+                                                KStandardGuiItem::cancel()) == KMessageBox::PrimaryAction) {
                 d->foundImageType = IMAGE_RAW;
                 d->imageFile = path;
             }
@@ -1216,4 +1229,4 @@ void K3b::ImageWritingDialog::dropEvent( QDropEvent* e )
     }
 }
 
-
+#include "moc_k3bimagewritingdialog.cpp"
