@@ -23,12 +23,17 @@ K3b::CddbOptionTab::CddbOptionTab( QWidget* parent )
 
     m_cddbKcm = 0;
 
-    const auto result = KPluginFactory::instantiatePlugin<KCModule>(KPluginMetaData(QStringLiteral("kcm_cddb")), this);
+    const auto result = KPluginFactory::instantiatePlugin<KCModule>(KPluginMetaData(QStringLiteral("plasma/kcms/systemsettings_qwidgets/kcm_cddb")), this);
 
     if (result) {
         m_cddbKcm = result.plugin;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         m_cddbKcm->layout()->setContentsMargins( 0, 0, 0, 0 );
         layout->addWidget( m_cddbKcm );
+#else
+        m_cddbKcm->widget()->layout()->setContentsMargins( 0, 0, 0, 0 );
+        layout->addWidget( m_cddbKcm->widget() );
+#endif
     } else {
         QLabel* label = new QLabel( i18n( "Unable to load KCDDB configuration module." ), this );
         label->setAlignment( Qt::AlignCenter );
@@ -57,4 +62,4 @@ void K3b::CddbOptionTab::apply()
     }
 }
 
-
+#include "moc_k3bcddboptiontab.cpp"
